YARP 2.3.9 (2011-08-19)                                                {#v2_3_9}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.8...v2.3.9`):

```
    18  Duarte Aragao <daragao@gmail.com>
    14  Paul Fitzpatrick <paulfitz@alum.mit.edu>
     4  Daniel Krieg <krieg@fias.uni-frankfurt.de>
     2  Ugo Pattacini <ugo.pattacini@iit.it>
     1  Fabien Benureau <fabien.benureau@gmail.com>
     1  Marco Randazzo <marco.randazzo@iit.it>
     1  Vadim Tikhanoff <vadim.tikhanoff@iit.it>
```
